@@ -16,7 +16,8 @@ engine_to_cdk_engine = {
     "oracle_s2": _rds.DatabaseInstanceEngine.oracle_se2,
     "oracle_ee": _rds.DatabaseInstanceEngine.oracle_ee,
     "mysql": _rds.DatabaseInstanceEngine.mysql,
-    "postgresql": _rds.DatabaseInstanceEngine.postgres
+    "postgresql": _rds.DatabaseInstanceEngine.postgres,
+    "sqlserver-se": _rds.DatabaseInstanceEngine.sql_server_se
 }
 
 engine_to_cluster_parameter_group_family = {
@@ -36,7 +37,8 @@ engine_to_version_class = {
     "oracle_s2": _rds.OracleEngineVersion,
     "oracle_ee": _rds.OracleEngineVersion,
     "aurora-postgresql": _rds.AuroraPostgresEngineVersion,
-    "postgresql": _rds.PostgresEngineVersion
+    "postgresql": _rds.PostgresEngineVersion,
+    "sqlserver-se":  _rds.SqlServerEngineVersion,
 }
 
 class Database(Construct):
@@ -96,6 +98,9 @@ class Database(Construct):
 
         dns_record: (Optional | str) The DNS record associated to the Database if multiple Databases
 
+        create_dns: (Optional | str) to enable/disable dns creation - format Boolean (`true`, `false`). Default: true
+
+
     """
     @property
     def security_group(self):
@@ -171,6 +176,7 @@ class Database(Construct):
         rubrik_backup="True",
         cloudwatch_audit_log=None,
         dns_record=None,
+        create_dns="True",
         **kwargs,
     ):
         super().__init__(scope, id, **kwargs)
@@ -211,6 +217,7 @@ class Database(Construct):
         is_not_cluster_compatible = not is_cluster_compatible
 
         is_oracle = "oracle" in database_engine
+        is_sqlserver = "sqlserver" in database_engine
 
         has_no_parameter_group = parameter_group is None and database_cluster_parameters_group_name is None
         has_no_defult_parameter_group = has_no_parameter_group and engine_to_cluster_parameter_group_family[database_engine] is None
@@ -367,7 +374,7 @@ class Database(Construct):
             self._cluster.add_rotation_single_user(
                 automatically_after= cdk.Duration.days(30)
             )
-            if not is_production:
+            if not is_production and create_dns.lower()=="true":
                 # Create DNS record
                 cluster_hostname=str(self._cluster.cluster_endpoint.hostname)
                 cluster_hostname = ''.join(cluster_hostname.split())
@@ -456,6 +463,10 @@ class Database(Construct):
                     # If user specified change to cloud watch log setting
                     cloudwatch_logs_exports = _rds.cloudwatch_logs_exports=["audit"]
 
+            if is_sqlserver:
+                # Default SQL server license model is LICENSE_INCLUDED
+                license_model = _rds.LicenseModel.LICENSE_INCLUDED
+
             self._instance = _rds.DatabaseInstance(
                 self,
                 "instance",
