@@ -159,6 +159,10 @@ class Microservice(Construct):
 
         rubrik_backup (str): to enable/disable Rubrik backup using tag `RubrikBackup` - format Boolean (`true`, `false`). Default: true
 
+        dns_record: (Optional | str) The DNS record associated to the Load Balancer. This is applied only in Development and QA environment. If multiple Load Balancers are included in the stack, the parameter is mandatory (Default is app_name)
+        
+        create_dns (Optional | str): to enable/disable dns creation - format Boolean (`true`, `false`). Default: true
+
     """
 
     @property
@@ -401,11 +405,13 @@ class Microservice(Construct):
 
         return tg
 
-    def create_network_load_balancer(self, scope, id, app_name, environment, network_load_balancer_ip_1, network_load_balancer_ip_2, network_load_balancer_subnet_1, network_load_balancer_subnet_2, dns_record=None):
+    def create_network_load_balancer(self, scope, id, app_name, environment, network_load_balancer_ip_1, network_load_balancer_ip_2, network_load_balancer_subnet_1, network_load_balancer_subnet_2, dns_record=None, create_dns="True"):
         """Create a network load balancer
 
          dns_record: (Optional | str) The DNS record associated to the Load Balancer. This is applied only in Development and QA environment. If multiple Load Balancers are included in the stack, the parameter is mandatory (Default is app_name)
 
+         create_dns: (Optional | str) to enable/disable dns creation - format Boolean (`true`, `false`). Default: true
+
         Args:
             id (str): the logical id of the newly created resource
         """
@@ -431,7 +437,7 @@ class Microservice(Construct):
         )
 
         # Create DNS record
-        if not is_production:
+        if not is_production and create_dns.lower() == "true":
             hosted_zone_id = aws_account["route53_hosted_zone_id"]
             domain_name = aws_account["route53_domain_name"]
             
@@ -459,7 +465,8 @@ class Microservice(Construct):
         use_cdn=False, 
         main_component_name=None, 
         load_balancer_idle_timeout_in_seconds=None, 
-        dns_record=None):
+        dns_record=None,
+        create_dns="True"):
         """Create a Load Balancer resource
         
         Args:
@@ -480,6 +487,7 @@ class Microservice(Construct):
 
             dns_record: (Optional | str) The DNS record associated to the Load Balancer. This is applied only in Development and QA environment. If multiple Load Balancers are included in the stack, the parameter is mandatory (Default is app_name)
         
+            create_dns: (Optional | str) to enable/disable dns creation - format Boolean (`true`, `false`). Default: true
         Returns:
             aws_alb.ApplicationLoadBalancer: the newly created Load Balancer
         """ 
@@ -548,7 +556,7 @@ class Microservice(Construct):
         cdk.Tags.of(alb).add("Environment", environment)
 
         # Create DNS record
-        if not is_production:
+        if not is_production and create_dns.lower() == "true":
             hosted_zone_id = aws_account["route53_hosted_zone_id"]
             domain_name = aws_account["route53_domain_name"]
             
@@ -697,6 +705,7 @@ class Microservice(Construct):
         load_balancer_idle_timeout_in_seconds=None,
         rubrik_backup="True",
         dns_record=None,
+        create_dns="True",
         **kwargs
     ):
         super().__init__(scope, id, **kwargs)
@@ -1019,7 +1028,8 @@ class Microservice(Construct):
                 network_load_balancer_ip_2,
                 network_load_balancer_subnet_1,
                 network_load_balancer_subnet_2,
-                dns_record=dns_record
+                dns_record=dns_record,
+                create_dns=create_dns
             )
             self.nlb.add_listener(
                 'instance_nlb_listener',
@@ -1040,7 +1050,8 @@ class Microservice(Construct):
                 use_cdn=use_cdn,
                 main_component_name=main_component_name,
                 load_balancer_idle_timeout_in_seconds=load_balancer_idle_timeout_in_seconds,
-                dns_record=dns_record
+                dns_record=dns_record,
+                create_dns=create_dns
             )
 
         if(is_application_load_balancer):
@@ -1099,7 +1110,7 @@ class Microservice(Construct):
                         token_endpoint=token_endpoint,
                         issuer=issuer,
                         client_id=client_id,
-                        client_secret= cdk.SecretValue(value=client_secret),
+                        client_secret= cdk.SecretValue(protected_value=client_secret),
                         user_info_endpoint=user_info_endpoint,
                         next=listener_default_action,
                     )
