@@ -1,8 +1,9 @@
-from aws_cdk import core, aws_iam as _iam
-from aws_cdk.core import Tags
-from aws_cdk_constructs.utils import normalize_environment_parameter
+import aws_cdk as cdk
+from constructs import Construct
+from aws_cdk import aws_iam as _iam
+from aws_cdk_constructs.utils import normalize_environment_parameter, get_version
 
-class ServiceUserForStaticAssets(core.Construct):
+class ServiceUserForStaticAssets(Construct):
     """Construct to create the Service User to deploy the project static files from a CD/CI pipeline
 
     Args:
@@ -28,7 +29,7 @@ class ServiceUserForStaticAssets(core.Construct):
 
     def __init__(
         self,
-        scope: core.Construct,
+        scope: Construct,
         id: str,
         app_name,
         environment,
@@ -40,8 +41,13 @@ class ServiceUserForStaticAssets(core.Construct):
         environment = normalize_environment_parameter(environment)
 
         # Apply mandatory tags
-        Tags.of(self).add("ApplicationName", app_name.lower().strip())
-        Tags.of(self).add("Environment", environment)
+        cdk.Tags.of(self).add("ApplicationName", app_name.lower().strip())
+        cdk.Tags.of(self).add("Environment", environment)
+
+        # Apply FAO CDK tags
+        cdk.Tags.of(self).add("fao-cdk-construct", "service_user_for_static_assets")
+        cdk.Tags.of(cdk.Stack.of(self)).add("fao-cdk-version", get_version())
+        cdk.Tags.of(cdk.Stack.of(self)).add("fao-cdk", "true")
 
         # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Create conditions
 
